==> fred_regal-0.6.0-py3-none-any.whl: regal/tests/test_keyset.py <==
from typing import Optional
from unittest import IsolatedAsyncioTestCase
from unittest.mock import sentinel

from fred_api.registry.keyset.keyset_history_types_pb2 import (
    KeysetHistoryRecord,
    KeysetHistoryReply,
    KeysetHistoryRequest,
)
from fred_api.registry.keyset.keyset_info_types_pb2 import (
    DnsKey as DnsKeyMessage,
    KeysetIdReply,
    KeysetIdRequest,
    KeysetInfoReply,
    KeysetInfoRequest,
)
from fred_api.registry.keyset.keyset_state_history_types_pb2 import (
    KeysetStateHistory,
    KeysetStateHistoryReply,
    KeysetStateHistoryRequest,
)
from fred_api.registry.keyset.keyset_state_types_pb2 import KeysetStateReply, KeysetStateRequest
from frgal.utils import AsyncTestClientMixin

from regal.keyset import DnsKey, Keyset, KeysetClient, KeysetHistoryId, KeysetId
from regal.tests.common import ObjectClientTestMixin


class TestKeysetClient(AsyncTestClientMixin, KeysetClient):
    """Test KeysetClient."""


class KeysetClientTest(ObjectClientTestMixin[TestKeysetClient], IsolatedAsyncioTestCase):
    """Test KeysetClient's methods."""

    grpc_namespace = "/Fred.Registry.Api.Keyset.Keyset"
    get_state_request = KeysetStateRequest
    get_state_reply = KeysetStateReply
    get_state_method = "get_keyset_state"
    get_history_request = KeysetHistoryRequest
    get_history_reply = KeysetHistoryReply
    get_history_method = "get_keyset_history"
    get_history_record = KeysetHistoryRecord
    get_state_history_request = KeysetStateHistoryRequest
    get_state_history_reply = KeysetStateHistoryReply
    get_state_history_method = "get_keyset_state_history"
    get_state_history_record = KeysetStateHistory.Record

    def setUp(self):
        self.client = TestKeysetClient(netloc=sentinel.netloc)

    async def test_get_keyset_id(self):
        keyset_id = KeysetId("kryten")
        reply = KeysetIdReply()
        reply.data.keyset_id.uuid.value = str(keyset_id)
        self.client.mock.return_value = reply

        response = await self.client.get_keyset_id("HANDLE")
        self.assertEqual(response, keyset_id)
        self.assertIsInstance(response, KeysetId)

        request = KeysetIdRequest()
        request.keyset_handle.value = "HANDLE"
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Keyset.Keyset/get_keyset_id",
            timeout=None,
        )

    async def _test_get_keyset_info(self, keyset_history_id: Optional[KeysetHistoryId] = None) -> None:
        dns_key = DnsKeyMessage()
        dns_key.flags = 256
        dns_key.protocol = 3
        dns_key.alg = 15
        dns_key.key = "some key"
        reply = KeysetInfoReply()
        reply.data.keyset_id.uuid.value = "kryten"
        if keyset_history_id:
            reply.data.keyset_history_id.uuid.value = keyset_history_id
        reply.data.keyset_handle.value = "HANDLE"
        reply.data.dns_keys.extend([dns_key])
        self.client.mock.return_value = reply

        response = await self.client.get_keyset_info(KeysetId("kryten"), history_id=keyset_history_id)

        self.assertEqual(
            response,
            Keyset(
                keyset_id=KeysetId("kryten"),
                keyset_history_id=keyset_history_id,
                keyset_handle="HANDLE",
                dns_keys=[DnsKey(flags=256, protocol=3, alg=15, key="some key")],
            ),
        )

        request = KeysetInfoRequest()
        request.keyset_id.uuid.value = "kryten"
        if keyset_history_id:
            request.keyset_history_id.uuid.value = keyset_history_id
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Keyset.Keyset/get_keyset_info",
            timeout=None,
        )

    async def test_get_keyset_info(self):
        await self._test_get_keyset_info()

    async def test_get_keyset_info_with_history_id(self):
        await self._test_get_keyset_info(keyset_history_id="nova-5")

==> fred_regal-1.0.1-py3-none-any.whl: regal/tests/test_keyset.py <==
from typing import Optional
from unittest import IsolatedAsyncioTestCase
from unittest.mock import sentinel

from fred_api.registry.keyset.keyset_history_types_pb2 import (
    KeysetHistoryRecord,
    KeysetHistoryReply,
    KeysetHistoryRequest,
)
from fred_api.registry.keyset.keyset_info_types_pb2 import (
    DnsKey as DnsKeyMessage,
    KeysetIdReply,
    KeysetIdRequest,
    KeysetInfoReply,
    KeysetInfoRequest,
)
from fred_api.registry.keyset.keyset_state_history_types_pb2 import (
    KeysetStateHistory,
    KeysetStateHistoryReply,
    KeysetStateHistoryRequest,
)
from fred_api.registry.keyset.keyset_state_types_pb2 import KeysetStateReply, KeysetStateRequest
from frgal.utils import AsyncTestClientMixin, make_awaitable

from regal.keyset import DnsKey, Keyset, KeysetClient, KeysetHistoryId, KeysetId
from regal.tests.common import ObjectClientTestMixin


class TestKeysetClient(AsyncTestClientMixin, KeysetClient):
    """Test KeysetClient."""


class KeysetClientTest(ObjectClientTestMixin[TestKeysetClient], IsolatedAsyncioTestCase):
    """Test KeysetClient's methods."""

    grpc_namespace = "/Fred.Registry.Api.Keyset.Keyset"
    get_state_request = KeysetStateRequest
    get_state_reply = KeysetStateReply
    get_state_method = "get_keyset_state"
    get_history_request = KeysetHistoryRequest
    get_history_reply = KeysetHistoryReply
    get_history_method = "get_keyset_history"
    get_history_record = KeysetHistoryRecord
    get_state_history_request = KeysetStateHistoryRequest
    get_state_history_reply = KeysetStateHistoryReply
    get_state_history_method = "get_keyset_state_history"
    get_state_history_record = KeysetStateHistory.Record

    def setUp(self):
        self.client = TestKeysetClient(netloc=sentinel.netloc)

    async def test_get_keyset_id(self):
        keyset_id = KeysetId("kryten")
        reply = KeysetIdReply()
        reply.data.keyset_id.uuid.value = str(keyset_id)
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_keyset_id("HANDLE")
        self.assertEqual(response, keyset_id)
        self.assertIsInstance(response, KeysetId)

        request = KeysetIdRequest()
        request.keyset_handle.value = "HANDLE"
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Keyset.Keyset/get_keyset_id",
            timeout=None,
        )

    async def _test_get_keyset_info(self, keyset_history_id: Optional[KeysetHistoryId] = None) -> None:
        dns_key = DnsKeyMessage()
        dns_key.flags = 256
        dns_key.protocol = 3
        dns_key.alg = 15
        dns_key.key = "some key"
        reply = KeysetInfoReply()
        reply.data.keyset_id.uuid.value = "kryten"
        if keyset_history_id:
            reply.data.keyset_history_id.uuid.value = keyset_history_id
        reply.data.keyset_handle.value = "HANDLE"
        reply.data.dns_keys.extend([dns_key])
        self.client.mock.return_value = make_awaitable(reply)

        response = await self.client.get_keyset_info(KeysetId("kryten"), history_id=keyset_history_id)

        self.assertEqual(
            response,
            Keyset(
                keyset_id=KeysetId("kryten"),
                keyset_history_id=keyset_history_id,
                keyset_handle="HANDLE",
                dns_keys=[DnsKey(flags=256, protocol=3, alg=15, key="some key")],
            ),
        )

        request = KeysetInfoRequest()
        request.keyset_id.uuid.value = "kryten"
        if keyset_history_id:
            request.keyset_history_id.uuid.value = keyset_history_id
        self.client.mock.assert_called_once_with(
            request,
            method="/Fred.Registry.Api.Keyset.Keyset/get_keyset_info",
            timeout=None,
        )

    async def test_get_keyset_info(self):
        await self._test_get_keyset_info()

    async def test_get_keyset_info_with_history_id(self):
        await self._test_get_keyset_info(keyset_history_id="nova-5")
